@@ -3,6 +3,10 @@ if (requireNamespace("Seurat", quietly = TRUE)) {
  suppressMessages(library("Seurat"))
 }
 
+if (requireNamespace("org.Hs.eg.db", quietly = TRUE)) {
+  suppressMessages(library("org.Hs.eg.db"))
+}
+
 if (requireNamespace("magrittr", quietly = TRUE)) {
  suppressMessages(library("magrittr"))
 }
@@ -21,6 +25,7 @@ human_chr_locations <- SCpubr::human_chr_locations
 progeny_activities <- readRDS(system.file("extdata/progeny_activities_example.rds", package = "SCpubr"))
 dorothea_activities <- readRDS(system.file("extdata/dorothea_activities_example.rds", package = "SCpubr"))
 enriched_terms <- readRDS(system.file("extdata/enriched_terms_example.rds", package = "SCpubr"))
+org.db <- AnnotationDbi::loadDb(system.file("./extdata/org.Hs.eg.sqlite", package = "org.Hs.eg.db"))
 
 
 # Get packages.
@@ -56,22 +61,22 @@ for (func in names(dependencies)){
 
 
 # Remove this for publication in CRAN.
-if (isFALSE(dep_check[["do_LigandReceptorPlot"]])){
-  liana_output <- readRDS(system.file("extdata/liana_output_example.rds", package = "SCpubr"))
-}
-
-if (isFALSE(dep_check[["do_DimPlot"]]) &
-    isFALSE(dep_check[["do_CorrelationPlot"]]) &
-    isFALSE(dep_check[["do_ChordDiagramPlot"]]) &
-    isTRUE(requireNamespace(pkg, quietly = TRUE)) &
-    isFALSE(dep_check[["save_Plot"]])){
-  p <- SCpubr::do_DimPlot(sample)
-  p.heatmap <- SCpubr::do_CorrelationPlot(sample)
-  data <- p.heatmap@ht_list$`Pearson coef.`@matrix
-  p.pheatmap <- pheatmap::pheatmap(data)
-  p.chord <- SCpubr::do_ChordDiagramPlot(sample = sample, from = "seurat_clusters", to = "orig.ident")
-  figure_path <- getwd()
-}
+#if (isFALSE(dep_check[["do_LigandReceptorPlot"]])){
+#  liana_output <- readRDS(system.file("extdata/liana_output_example.rds", package = "SCpubr"))
+#}
+#
+#if (isFALSE(dep_check[["do_DimPlot"]]) &
+#    isFALSE(dep_check[["do_CorrelationPlot"]]) &
+#    isFALSE(dep_check[["do_ChordDiagramPlot"]]) &
+#    isTRUE(requireNamespace(pkg, quietly = TRUE)) &
+#    isFALSE(dep_check[["save_Plot"]])){
+#  p <- SCpubr::do_DimPlot(sample)
+#  p.heatmap <- SCpubr::do_CorrelationPlot(sample)
+#  data <- p.heatmap@ht_list$`Pearson coef.`@matrix
+#  p.pheatmap <- pheatmap::pheatmap(data)
+#  p.chord <- SCpubr::do_ChordDiagramPlot(sample = sample, from = "seurat_clusters", to = "orig.ident")
+#  figure_path <- getwd()
+#}
 
 
 #monocle_sample <- sample
